@@ -10,7 +10,7 @@ pub struct Resp {}
 pub struct Body(Vec<u8>);
 #[derive(Clone, PartialEq, Eq, Hash, Debug)]
 pub struct HeaderName(String);
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct HeaderValue(Vec<u8>);
 
 impl Req {
@@ -84,6 +84,7 @@ impl Resp {
     }
 }
 
+/// Backend specific error
 #[derive(Debug)]
 pub struct Error {}
 impl std::error::Error for Error {}
@@ -125,3 +126,8 @@ impl<'a> TryFrom<&'a str> for HeaderValue {
         Ok(HeaderValue(t.as_bytes().to_vec()))
     }
 }
+impl From<std::convert::Infallible> for Error {
+    fn from(_e: std::convert::Infallible) -> Self {
+        unreachable!();
+    }
+}
